@@ -1,33 +1,20 @@
 /*
-  Copyright (c) 2015-2020 Laurent Montel <montel@kde.org>
+    SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
 
-  This library is free software; you can redistribute it and/or modify it
-  under the terms of the GNU Library General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or (at your
-  option) any later version.
-
-  This library is distributed in the hope that it will be useful, but WITHOUT
-  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-  License for more details.
-
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to the
-  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-  02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 
 */
 
 #include <QApplication>
 
-#include <config-kdebugsettings.h>
-#include "kdebugsettingsdialog.h"
 #include "changedebugmodejob.h"
+#include "kdebugsettingsdialog.h"
+#include <config-kdebugsettings.h>
 
-#include <KLocalizedString>
 #include <KAboutData>
-#include <QCommandLineParser>
 #include <KDBusService>
+#include <KLocalizedString>
+#include <QCommandLineParser>
 #include <QStandardPaths>
 
 #include <iostream>
@@ -39,9 +26,12 @@ int main(int argc, char **argv)
 
     QApplication app(argc, argv);
 
-    KAboutData aboutData(QStringLiteral("kdebugsettings"), i18n("KDebugSettings"), QStringLiteral(KDEBUGSETTINGS_VERSION),
-                         i18n("Configure debug settings"), KAboutLicense::GPL_V2,
-                         i18n("(c) 2015-2020 kdebugsettings authors"));
+    KAboutData aboutData(QStringLiteral("kdebugsettings"),
+                         i18n("KDebugSettings"),
+                         QStringLiteral(KDEBUGSETTINGS_VERSION),
+                         i18n("Configure debug settings"),
+                         KAboutLicense::GPL_V2,
+                         i18n("(c) 2015-2021 kdebugsettings authors"));
     aboutData.addAuthor(i18n("Laurent Montel"), i18n("Maintainer"), QStringLiteral("montel@kde.org"));
     KAboutData::setApplicationData(aboutData);
 
@@ -56,11 +46,12 @@ int main(int argc, char **argv)
     QCommandLineOption switchOffDebugOption(QStringLiteral("disable-full-debug"), i18n("Disable full debug for all modules."));
     parser.addOption(switchOffDebugOption);
 
-    QCommandLineOption changeDebugSettingOption(QStringLiteral("debug-mode"), i18n("Change debug mode as console (in console)"), QStringLiteral("Full|Info|Warning|Critical|Off"));
+    QCommandLineOption changeDebugSettingOption(QStringLiteral("debug-mode"),
+                                                i18n("Change debug mode as console (in console)"),
+                                                QStringLiteral("Full|Info|Warning|Critical|Off"));
     parser.addOption(changeDebugSettingOption);
-    parser.addPositionalArgument(
-        QStringLiteral("logging category name"),
-        i18n("Specify logging category name that you want to change debug mode (in console)"));
+    parser.addPositionalArgument(QStringLiteral("logging category name"),
+                                 i18n("Specify logging category name that you want to change debug mode (in console)"));
 
     parser.process(app);
     aboutData.processCommandLine(&parser);
@@ -99,7 +90,7 @@ int main(int argc, char **argv)
         return 1;
     } else {
         KDBusService service(KDBusService::Unique);
-        auto *dialog = new KDebugSettingsDialog;
+        auto dialog = new KDebugSettingsDialog;
         const int ret = dialog->exec();
         delete dialog;
         return ret;
